@@ -6,11 +6,11 @@
 
 typedef struct php_ds_deque_iterator {
     zend_object_iterator    intern;
-    zend_long               position;
+    zend_object            *object;
     ds_deque_t             *deque;
+    zend_long               position;
 } php_ds_deque_iterator_t;
 
-zend_object_iterator *php_ds_deque_get_iterator_ex(zend_class_entry *ce, zval *object, int by_ref, ds_deque_t *deque);
-zend_object_iterator *php_ds_deque_get_iterator(zend_class_entry *ce, zval *object, int by_ref);
+zend_object_iterator *php_ds_deque_get_iterator(zend_class_entry *ce, zval *obj, int by_ref);
 
 #endif
