@@ -4,9 +4,9 @@
 
 static void php_ds_queue_iterator_dtor(zend_object_iterator *iter)
 {
-    zval tmp;
-    ZVAL_OBJ(&tmp, (zend_object *) ((ds_queue_iterator_t *) iter)->queue);
-    zval_ptr_dtor(&tmp);
+    ds_queue_iterator_t *iterator = (ds_queue_iterator_t *) iter;
+
+    OBJ_RELEASE(iterator->object);
 }
 
 static int php_ds_queue_iterator_valid(zend_object_iterator *iter)
@@ -23,12 +23,12 @@ static void php_ds_queue_iterator_get_current_key(zend_object_iterator *iter, zv
     ZVAL_LONG(key, ((ds_queue_iterator_t *) iter)->position);
 }
 
-static void php_ds_queue_iterator_set_current(php_ds_queue_t *queue, zval *data)
+static void php_ds_queue_iterator_set_current(ds_queue_t *queue, zval *data)
 {
-    if (QUEUE_IS_EMPTY(queue->queue)) {
+    if (QUEUE_IS_EMPTY(queue)) {
         ZVAL_UNDEF(data);
     } else {
-        ds_queue_pop(queue->queue, data);
+        ds_queue_pop(queue, data);
         Z_TRY_DELREF_P(data);
     }
 }
@@ -69,15 +69,16 @@ zend_object_iterator *php_ds_queue_get_iterator(zend_class_entry *ce, zval *obje
     zend_iterator_init((zend_object_iterator*) iterator);
 
     iterator->intern.funcs = &php_ds_queue_iterator_funcs;
-    iterator->queue        = (php_ds_queue_t*) (Z_OBJ_P(object));
+    iterator->queue        = Z_DS_QUEUE_P(object);
+    iterator->object       = Z_OBJ_P(object);
     iterator->position     = 0;
 
     // Add a reference to the object so that it doesn't get collected when
     // the iterated object is implict, eg. foreach ($obj->getInstance() as $value){ ... }
 #if PHP_VERSION_ID >= 70300
-    GC_ADDREF((zend_object *) iterator->queue);
+    GC_ADDREF(iterator->object);
 #else
-    ++GC_REFCOUNT((zend_object *) iterator->queue);
+    ++GC_REFCOUNT(iterator->object);
 #endif
 
     return (zend_object_iterator *) iterator;
